# coding: utf-8
"""
    sickle
    ~~~~~~

    An OAI-PHM client.

    :copyright: Copright 2013 Mathias Loesch
"""

__version__ = '0.3'


from .app import Sickle, OAIResponse
